@@ -14,27 +14,10 @@ async function main() {
     // await hre.run('compile');
 
     // We get the contract to deploy
-    const ABC = await hre.ethers.getContractFactory("ABC");
-    const abc = await ABC.deploy();
-    await abc.deployed();
-    console.log("ABC deployed to:", abc.address);
-
-
-    const Bar = await hre.ethers.getContractFactory("Bar");
-    const bar = await Bar.deploy();
-    await bar.deployed();
-    console.log("Bar deployed to:", bar.address);
-
-
-    const Foo = await hre.ethers.getContractFactory("Foo");
-    const foo = await Foo.deploy();
-    await foo.deployed();
-    console.log("Foo deployed to:", foo.address);
-
-    const Migrations = await hre.ethers.getContractFactory("Migrations");
-    const migrations = await Migrations.deploy();
-    await migrations.deployed();
-    console.log("Migrations deployed to:", migrations.address);
+    const LessonTestContract = await hre.ethers.getContractFactory("LessonTestContract");
+    const lessonTestContract = await LessonTestContract.deploy();
+    await lessonTestContract.deployed();
+    console.log("LessonTestContract deployed at:", lessonTestContract.address);
 }
 
 // We recommend this pattern to be able to use async/await everywhere
