@@ -14,6 +14,10 @@ class FaaSError(Exception):
     pass
 
 
+class EmptyArtifactsError(Exception):
+    pass
+
+
 class AuthorizationError(FaaSError):
     pass
 
@@ -83,6 +87,14 @@ class BuildArtifactsError(click.exceptions.ClickException):
     pass
 
 
+class QuickCheckError(click.exceptions.ClickException):
+    pass
+
+
+class FuzzingLessonsError(click.exceptions.ClickException):
+    pass
+
+
 class SourceError(BrownieError):
     """Exception raised for errors the source and AST of a source file"""
 
