@@ -37,14 +37,6 @@ class DapptoolsArtifacts(IDEArtifacts):
         files = list(os.walk(root_dir))[0][2]
         return ".dapprc" in files
 
-    @property
-    def contracts(self) -> List[Contract]:
-        return self.fetch_data()[0]
-
-    @property
-    def sources(self) -> Dict[str, Source]:
-        return self.fetch_data()[1]
-
     @staticmethod
     def get_default_build_dir() -> Path:
         return Path.cwd().joinpath("out")
@@ -110,20 +102,42 @@ class DapptoolsArtifacts(IDEArtifacts):
         result_contracts: Dict[str, List[Contract]] = {}
         result_sources = {}
 
+        source_ids: List[int] = []
+
+        for source_file_path, source_file in source_files.items():
+            # We can select any dict on the build_files_by_source_file[source_file] array
+            # because the .source and .ast values will be the same in all.
+            target_file = build_files_by_source_file[source_file_path]
+            result_sources[source_file_path] = {
+                "fileIndex": source_file["id"],
+                "source": get_content_from_file(source_file_path),
+                "ast": source_file["ast"],
+            }
+            source_ids.append(source_file["id"])
+
+            if (
+                self.map_to_original_source
+                and Path(source_file_path + ".original").is_file()
+            ):
+                # we check if the current source file has a non instrumented version
+                # if it does, we include that one as the source code
+                result_sources[source_file_path]["source"] = get_content_from_file(
+                    source_file_path + ".original"
+                )
+
         # ( 'contracts/Token.sol', {'allSourcePaths':..., 'deployedSourceMap': ... } )
         for source_file, contracts in build_files_by_source_file.items():
             result_contracts[source_file] = []
             for (contract_name, contract) in contracts.items():
                 # We get the build items from dapptools and rename them into the properties used by the FaaS
                 try:
-                    ignored_sources = set()
-                    for generatedSource in contract["evm"]["deployedBytecode"].get(
-                        "generatedSources", []
-                    ):
-                        if generatedSource["language"].lower() == "yul" and type(
-                            generatedSource["id"] is int
-                        ):
-                            ignored_sources.add(generatedSource["id"])
+                    ignored_sources = self.get_ignored_sources(
+                        generated_sources=contract["evm"]["deployedBytecode"].get(
+                            "generatedSources"
+                        ),
+                        source_map=contract["evm"]["deployedBytecode"]["sourceMap"],
+                        source_ids=source_ids,
+                    )
 
                     result_contracts[source_file] += [
                         {
@@ -141,7 +155,7 @@ class DapptoolsArtifacts(IDEArtifacts):
                             "bytecode": contract["evm"]["bytecode"]["object"],
                             "contractName": contract_name,
                             "mainSourceFile": source_file,
-                            "ignoredSources": list(sorted(ignored_sources)),
+                            "ignoredSources": ignored_sources,
                         }
                     ]
                 except KeyError as e:
@@ -149,25 +163,4 @@ class DapptoolsArtifacts(IDEArtifacts):
                         f"Build artifact did not contain expected key. Contract: {contract}: \n{e}"
                     )
 
-        for source_file_path, source_file in source_files.items():
-            file_index = str(source_file["id"])
-
-            # We can select any dict on the build_files_by_source_file[source_file] array
-            # because the .source and .ast values will be the same in all.
-            target_file = build_files_by_source_file[source_file_path]
-            result_sources[source_file_path] = {
-                "fileIndex": file_index,
-                "source": get_content_from_file(source_file_path),
-                "ast": source_file["ast"],
-            }
-
-            if (
-                self.map_to_original_source
-                and Path(source_file_path + ".original").is_file()
-            ):
-                # we check if the current source file has a non instrumented version
-                # if it does, we include that one as the source code
-                result_sources[source_file_path]["source"] = get_content_from_file(
-                    source_file_path + ".original"
-                )
         return result_contracts, result_sources
